==> pqconnect_1.2.1.orig.tar.gz: pqconnect-1.2.1/doc/papers.md <==
The paper
["PQConnect: Automated Post-Quantum End-to-End Tunnels"](pqconnect-20241206.pdf)
by Daniel J. Bernstein,
Tanja Lange,
Jonathan Levin,
and
Bo-Yin Yang
will appear at the Network and Distributed System Security (NDSS) Symposium 2025.

Further reading:

* Tanja Lange and Jonathan Levin,
  ["PQConnect: Automated Post-Quantum End-to-End Tunnels"](20241227.pdf),
  invited talk at
  International Collaboration on Post-Quantum Cryptography and Cybersecurity: Retrospect and Prospects,
  2024.

* Tanja Lange,
  ["How to fit an elephant into a Smart car – PQC for small devices"](https://hyperelliptic.org/tanja/vortraege/20220627-esa-lange.pdf),
  invited talk at ESA Workshop on "Secure Communications for Space Missions in the Post-Quantum Era" at European Space Research and Technology Centre (ESTEC),
  2022.

* Tanja Lange,
  ["Code-based cryptography for secure communication"](https://hyperelliptic.org/tanja/vortraege/20220427-oaxaca.pdf),
  invited talk at Algebraic Methods in Coding Theory and Communication,
  2022.

* Daniel J. Bernstein and Tanja Lange,
  ["The transition to post-quantum cryptography"](https://hyperelliptic.org/tanja/vortraege/slides-dan+tanja-20220401-transition-16x9.pdf),
  invited talk at International Distinguished Lecture Series at EECS at National Taiwan University,
  2021.

* Tanja Lange,
  ["Transitioning to post-quantum: How PQC affects protocols and what we can do today?"](https://hyperelliptic.org/tanja/vortraege/icmc-21.pdf),
  invited talk at International Cryptographic Module Conference 2021.

* Jonathan Levin,
  ["PQConnect: An Automated Boring Protocol for Quantum-Secure Tunnels"](https://research.tue.nl/en/studentTheses/pqconnect),
  master's thesis,
  Eindhoven University of Technology,
  2021.

* Daniel J. Bernstein,
  ["Internet: Integration"](https://pqcrypto.eu.org/deliverables/d2.5.pdf),
  PQCRYPTO deliverable D2.5,
  2018.

* Daniel J. Bernstein,
  ["The post-quantum Internet"](https://cr.yp.to/talks.html#2016.02.24),
  invited talk at PQCrypto 2016.

PQConnect builds on work by many further researchers.
See the NDSS 2025 paper for references.

==> pqconnect_1.2.2.orig.tar.gz: pqconnect-1.2.2/doc/papers.md <==
The paper
["PQConnect: Automated Post-Quantum End-to-End Tunnels"](pqconnect-20241206.pdf)
by Daniel J. Bernstein,
Tanja Lange,
Jonathan Levin,
and
Bo-Yin Yang
has appeared at the Network and Distributed System Security (NDSS) Symposium 2025.
The
[talk slides](https://www.jlev.in/talks/20250226.pdf)
are also available.

Further reading:

* Tanja Lange and Jonathan Levin,
  ["PQConnect: Automated Post-Quantum End-to-End Tunnels"](20241227.pdf),
  invited talk at
  International Collaboration on Post-Quantum Cryptography and Cybersecurity: Retrospect and Prospects,
  2024.

* Tanja Lange,
  ["How to fit an elephant into a Smart car – PQC for small devices"](https://hyperelliptic.org/tanja/vortraege/20220627-esa-lange.pdf),
  invited talk at ESA Workshop on "Secure Communications for Space Missions in the Post-Quantum Era" at European Space Research and Technology Centre (ESTEC),
  2022.

* Tanja Lange,
  ["Code-based cryptography for secure communication"](https://hyperelliptic.org/tanja/vortraege/20220427-oaxaca.pdf),
  invited talk at Algebraic Methods in Coding Theory and Communication,
  2022.

* Daniel J. Bernstein and Tanja Lange,
  ["The transition to post-quantum cryptography"](https://hyperelliptic.org/tanja/vortraege/slides-dan+tanja-20220401-transition-16x9.pdf),
  invited talk at International Distinguished Lecture Series at EECS at National Taiwan University,
  2021.

* Tanja Lange,
  ["Transitioning to post-quantum: How PQC affects protocols and what we can do today?"](https://hyperelliptic.org/tanja/vortraege/icmc-21.pdf),
  invited talk at International Cryptographic Module Conference 2021.

* Jonathan Levin,
  ["PQConnect: An Automated Boring Protocol for Quantum-Secure Tunnels"](https://research.tue.nl/en/studentTheses/pqconnect),
  master's thesis,
  Eindhoven University of Technology,
  2021.

* Daniel J. Bernstein,
  ["Internet: Integration"](https://pqcrypto.eu.org/deliverables/d2.5.pdf),
  PQCRYPTO deliverable D2.5,
  2018.

* Daniel J. Bernstein,
  ["The post-quantum Internet"](https://cr.yp.to/talks.html#2016.02.24),
  invited talk at PQCrypto 2016.

PQConnect builds on work by many further researchers.
See the NDSS 2025 paper for references.
